=======================
Blanc Django Admin Skin
=======================

A collection of files which can restyle the Django admin site. The CSS file
provided with it works in addition to the default Django admin CSS, overriding
the default styles where needed with our improved look.
